@@ -1,5 +1,7 @@
 package CGI::Portal;
-# Copyright (c) 2005 Alexander David. All rights reserved.
+# Copyright (c) 2008 Alexander David P. All rights reserved.
+#
+# Prepare and run the requested class code, then print
 
 use strict;
 use CGI::Portal::RDB;
@@ -7,52 +9,66 @@ use CGI::Portal::Scripts::Header;
 use CGI::Portal::Scripts::Footer;
 use CGI;
 use HTML::Template;
-use vars qw($VERSION);
-$VERSION = "0.08";
 
-my $h;
-my $f;
-my $e;
+use vars qw($VERSION);
+$VERSION = "0.10";
 
 1;
 
+            # Prepare and run the requested class code, then print
 sub activate {
   my $conf = shift;
   my $cgi = new CGI();
   my @v = $cgi->param;
   my %in;
+
+            # Loop thru params and assign %in
   foreach my $f (@v){
     my $v = $cgi->param($f);
+
+            # Remove tags
     $v =~ s/<.*\r*\n*.*>//g;
+
     $in{$f} = $v;
   }
 
+            # Get the database handle object
   my $rdb = CGI::Portal::RDB->new("DBI:$conf->{'database_type'}:database=$conf->{'database_name'};host=$conf->{'database_host'};", $conf->{'database_user'}, $conf->{'database_passw'});
 
+            # This is going to be passed to the CGI::Portal::Scripts object
   my $i = {'in',      \%in,
            'rdb',     $rdb,
            'conf',    $conf};
 
+            # Assign the default action
   my $c = "CGI::Portal::Scripts::$conf->{'actions'}[0]";
+
+            # Loop thru actions and assign if one is chosen
   foreach my $a (@{$conf->{'actions'}}) {
     if ($in{'action'} eq $a){
       $c = "CGI::Portal::Scripts::$a";
     }
   }
+
+            # Create an object, pass $i and call the launch() subroutine
   eval "use $c;";
-  $e = $c->new($i);
+  my $e = $c->new($i);
   $e->launch;
 
-  $h = CGI::Portal::Scripts::Header->new({});
-  $h->launch($e);
-  $f = CGI::Portal::Scripts::Footer->new({});
-  $f->launch($e);
+            # Run Headers launch()
+  my $header = CGI::Portal::Scripts::Header->new({});
+  $header->launch($e);
 
+            # Run Footers launch()
+  my $footer = CGI::Portal::Scripts::Footer->new({});
+  $footer->launch($e);
+
+            # Print
   print $e->{'cookies'};
   print $cgi->header;
-  print $h->{'out'};
+  print $header->{'out'};
   print $e->{'out'};
-  print $f->{'out'};
+  print $footer->{'out'};
 }
 
 =head1 NAME
@@ -85,7 +101,7 @@ CGI::Portal - Extensible Framework for Multiuser Applications
                            'session_additional'  => "",
 
 
-                           # Modules in the CGI::Portal::Scripts namespace, the first is the default action
+                           # Classes in the CGI::Portal::Scripts namespace, the first is the default action
 
                            'actions'             => ["logon", "logoff", "register", "profile", "changepw", "emailpw"],
 
@@ -108,7 +124,7 @@ It requires a database including a user and a sessions table, a collection of HT
 style templates and a properly configured startup script. To start with CGI::Portal you
 may want to install the provided templates at http://cgi-portal.sourceforge.net/
 
-All requests access through the startup script, and are handled by the module in
+All requests access through the startup script, and are handled by the class in
 the CGI::Portal::Scripts namespace that corresponds to the desired action. Above shown
 actions are included in CGI::Portal.
 
@@ -119,8 +135,8 @@ For example, portal.cgi?action=foo calls CGI::Portal::Scripts::foo::launch()
 =head2 activate
 
 CGI::Portal::activate($conf) takes a reference to the configuration hash, collects
-input parameters, creates a database object, and passes those on to your module
-for creating an object instance. It then runs your modules "launch" method and
+input parameters, creates a database object, and passes those on to your class
+for creating an object instance. It then runs your class "launch" method and
 concludes by doing the printing for you. This function is called once from your
 startup script.
 
